@@ -678,7 +678,7 @@ _make_gtk_label_bold (GtkLabel *label)
    * theme or user prefs, since the font desc only has the
    * weight flag turned on.
    */
-  gtk_widget_modify_font (GTK_WIDGET (label), font_desc);
+  gtk_widget_override_font (GTK_WIDGET (label), font_desc);
 
   pango_font_description_free (font_desc);
 }
@@ -698,7 +698,7 @@ _make_gtk_label_normal (GtkLabel *label)
    * theme or user prefs, since the font desc only has the
    * weight flag turned on.
    */
-  gtk_widget_modify_font (GTK_WIDGET (label), font_desc);
+  gtk_widget_override_font (GTK_WIDGET (label), font_desc);
 
   pango_font_description_free (font_desc);
 }
