@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #include <libwnck/libwnck.h>
 
@@ -23,25 +23,6 @@ wnck_pager_display_mode_get_type (void)
 
 
 /* enumerations from "screen.h" */
-static const GEnumValue _wnck_motion_direction_values[] = {
-  { WNCK_MOTION_UP, "WNCK_MOTION_UP", "up" },
-  { WNCK_MOTION_DOWN, "WNCK_MOTION_DOWN", "down" },
-  { WNCK_MOTION_LEFT, "WNCK_MOTION_LEFT", "left" },
-  { WNCK_MOTION_RIGHT, "WNCK_MOTION_RIGHT", "right" },
-  { 0, NULL, NULL }
-};
-
-GType
-wnck_motion_direction_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("WnckMotionDirection", _wnck_motion_direction_values);
-
-  return type;
-}
-
 static const GEnumValue __wncklayoutorientation___wnck_layout_orientation_values[] = {
   { WNCK_LAYOUT_ORIENTATION_HORIZONTAL, "WNCK_LAYOUT_ORIENTATION_HORIZONTAL", "horizontal" },
   { WNCK_LAYOUT_ORIENTATION_VERTICAL, "WNCK_LAYOUT_ORIENTATION_VERTICAL", "vertical" },
@@ -119,7 +100,7 @@ wnck_client_type_get_type (void)
 
 
 /* enumerations from "window.h" */
-static const GEnumValue _wnck_window_state_values[] = {
+static const GFlagsValue _wnck_window_state_values[] = {
   { WNCK_WINDOW_STATE_MINIMIZED, "WNCK_WINDOW_STATE_MINIMIZED", "minimized" },
   { WNCK_WINDOW_STATE_MAXIMIZED_HORIZONTALLY, "WNCK_WINDOW_STATE_MAXIMIZED_HORIZONTALLY", "maximized-horizontally" },
   { WNCK_WINDOW_STATE_MAXIMIZED_VERTICALLY, "WNCK_WINDOW_STATE_MAXIMIZED_VERTICALLY", "maximized-vertically" },
@@ -142,12 +123,12 @@ wnck_window_state_get_type (void)
   static GType type = 0;
 
   if (!type)
-    type = g_enum_register_static ("WnckWindowState", _wnck_window_state_values);
+    type = g_flags_register_static ("WnckWindowState", _wnck_window_state_values);
 
   return type;
 }
 
-static const GEnumValue _wnck_window_actions_values[] = {
+static const GFlagsValue _wnck_window_actions_values[] = {
   { WNCK_WINDOW_ACTION_MOVE, "WNCK_WINDOW_ACTION_MOVE", "move" },
   { WNCK_WINDOW_ACTION_RESIZE, "WNCK_WINDOW_ACTION_RESIZE", "resize" },
   { WNCK_WINDOW_ACTION_SHADE, "WNCK_WINDOW_ACTION_SHADE", "shade" },
@@ -176,7 +157,7 @@ wnck_window_actions_get_type (void)
   static GType type = 0;
 
   if (!type)
-    type = g_enum_register_static ("WnckWindowActions", _wnck_window_actions_values);
+    type = g_flags_register_static ("WnckWindowActions", _wnck_window_actions_values);
 
   return type;
 }
@@ -230,7 +211,7 @@ wnck_window_gravity_get_type (void)
   return type;
 }
 
-static const GEnumValue _wnck_window_move_resize_mask_values[] = {
+static const GFlagsValue _wnck_window_move_resize_mask_values[] = {
   { WNCK_WINDOW_CHANGE_X, "WNCK_WINDOW_CHANGE_X", "x" },
   { WNCK_WINDOW_CHANGE_Y, "WNCK_WINDOW_CHANGE_Y", "y" },
   { WNCK_WINDOW_CHANGE_WIDTH, "WNCK_WINDOW_CHANGE_WIDTH", "width" },
@@ -244,11 +225,32 @@ wnck_window_move_resize_mask_get_type (void)
   static GType type = 0;
 
   if (!type)
-    type = g_enum_register_static ("WnckWindowMoveResizeMask", _wnck_window_move_resize_mask_values);
+    type = g_flags_register_static ("WnckWindowMoveResizeMask", _wnck_window_move_resize_mask_values);
 
   return type;
 }
 
 
-/* Generated data ends here */
+/* enumerations from "workspace.h" */
+static const GEnumValue _wnck_motion_direction_values[] = {
+  { WNCK_MOTION_UP, "WNCK_MOTION_UP", "up" },
+  { WNCK_MOTION_DOWN, "WNCK_MOTION_DOWN", "down" },
+  { WNCK_MOTION_LEFT, "WNCK_MOTION_LEFT", "left" },
+  { WNCK_MOTION_RIGHT, "WNCK_MOTION_RIGHT", "right" },
+  { 0, NULL, NULL }
+};
+
+GType
+wnck_motion_direction_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    type = g_enum_register_static ("WnckMotionDirection", _wnck_motion_direction_values);
+
+  return type;
+}
+
+
+
 
